==> phpgroupware-jp-0.9.16.003-pre1.tar.bz2: phpgroupware/eldaptir/edit.php <==
<?php
	/**************************************************************************\
	* phpGroupWare - - eLDAPtir - LDAP Administration                          *
	* http://www.phpgroupware.org                                              *
	* Written by Miles Lott <milosch@phpgroupware.org>                         *
	* --------------------------------------------                             *
	*  This program is free software; you can redistribute it and/or modify it *
	*  under the terms of the GNU General Public License as published by the   *
	*  Free Software Foundation; either version 2 of the License, or (at your  *
	*  option) any later version.                                              *
	\**************************************************************************/

	/* $Id: edit.php,v 1.1.1.2.8.1 2004/09/26 11:15:52 kazuyan Exp $ */

	$dn = $_GET['dn'] ? @urldecode($_GET['dn']) : $_POST['dn'];
	$ou = $_GET['ou'] ? @urldecode($_GET['ou']) : $_POST['ou'];
	if (!$dn)
	{
		$GLOBALS['phpgw_info']['flags'] = array(
			'noappheader' => True,
			'nonavbar'    => True,
			'noheader'    => True
		);
		include('../header.inc.php');
		Header('Location: ' . $GLOBALS['phpgw']->link('/eldaptir/index.php'));
	}

	$GLOBALS['phpgw_info']['flags'] = array(
		'enable_nextmatchs_class' => True,
		'currentapp'              => 'eldaptir',
		'parent_page'             => 'viewou.php'
	);
	include('../header.inc.php');
	$server_id = get_var('server_id', array('GET', 'POST'));
    foreach($_POST as $key => $val)
    {
    	$$key = get_var($key,array('POST'));
    }
	$servers = servers();
	$server_type = $servers[$server_id]['type'];
	$ldapobj = CreateObject('eldaptir.ldap',$servers[$server_id]);
	$codecv = CreateObject('phpgwapi.codecv');

	if ($submit && $dn)
	{
		// This doesn't touch LDAP yet, just displays what might occur
		echo "<br>Form values:";
		$thisdn = urldecode($dn);
		$entry  = $ldapobj->read($thisdn);
		unset($ldapobj->entry);
		while (list($key,$objectclass) = each($entry[0]['objectclass']))
		{
			$object = strtolower($objectclass);
			if($ldapobj->schema->$object)
			{
				echo "<br><br>Checking: ".$object."\n";
				@reset($ldapobj->schema->$object);
				$ldapobj->entry['objectclass'][] = $object;
				while(list($attrib,$req) = @each($ldapobj->schema->$object))
				{
					$lattrib = strtolower($attrib);		
					echo "<br>". $object."[".$lattrib."] = "
						. ${$object}[$lattrib]."\n";

					if (${$object}[$lattrib] && !$ldapobj->entry[$lattrib])
					{
						$ldapobj->entry[$lattrib] = $codecv->euctoutf8(${$object}[$lattrib]);
					}
					elseif ((!isset(${$object}[$lattrib]) || ${$object}[$lattrib] == '') && $entry[0][$lattrib])
					{
						$ldapobj->entry[$lattrib] = Array();
					}
				}
			}
		}
		echo "<br><br>Entry values:";
		while (list($key,$val) = each($entry[0]))
		{
			if($ldapobj->clean($val))
			{
				if (is_array($val))
				{
					while(list($v) = each($val))
					{
						if($ldapobj->clean($v))
						{
							echo '<br>arr '.$codecv->utf8toeuc($v).': '.$codecv->utf8toeuc($entry[0][$v][0])."\n";
						}
					}
				}
				else
				{
					echo '<br>str '.$codecv->utf8toeuc($val).': '.$codecv->utf8toeuc($entry[0][$val][0])."\n";
				}
			}
		}
		$ldapobj->update($thisdn);
		echo '<div align="center"><a href="'.$GLOBALS['phpgw']->link('/eldaptir/viewou.php','ou='.$ou.'&nisMapName='.$nisMapName.'&server_id='.$server_id).
		'">'.lang('Back').'</a></div>';
		$GLOBALS['phpgw']->common->phpgw_footer();
		exit;
		//...
	}

	$GLOBALS['phpgw']->template->set_unknowns('remove');
	$GLOBALS['phpgw']->template->set_file(array('edit' => 'edit.tpl'));
	$GLOBALS['phpgw']->template->set_block('edit','header','header');
	$GLOBALS['phpgw']->template->set_block('edit','row','row');
	$GLOBALS['phpgw']->template->set_block('edit','footer','footer');

	$GLOBALS['phpgw']->template->set_var('title','<a href="'.$GLOBALS['phpgw']->link('/eldaptir','server_id='.$server_id).'">'.lang("eldaptir")."</a>\n");
	$GLOBALS['phpgw']->template->set_var('th_bg',$GLOBALS['phpgw_info']['theme']['th_bg']);
	$GLOBALS['phpgw']->template->set_var('tr_color1',$GLOBALS['phpgw_info']['theme']['row_on']);
	$GLOBALS['phpgw']->template->set_var('tr_color2',$GLOBALS['phpgw_info']['theme']['row_off']);
	$GLOBALS['phpgw']->template->set_var('lang_cancel',lang('Cancel'));
	$GLOBALS['phpgw']->template->set_var('lang_addobj',lang('Add').' '.lang('Objectclass'));
	$GLOBALS['phpgw']->template->set_var('lang_submit',lang('Submit'));
	$GLOBALS['phpgw']->template->set_var('lang_dn',lang('dn'));
	$GLOBALS['phpgw']->template->set_var('lang_obj',lang('Objectclass'));
	$GLOBALS['phpgw']->template->set_var('lang_attr',lang('Attribute'));
	$GLOBALS['phpgw']->template->set_var('lang_value',lang('Value'));
	$GLOBALS['phpgw']->template->set_var('lang_rule',lang('Rule'));
	$GLOBALS['phpgw']->template->set_var('action_url',$GLOBALS['phpgw']->link('/eldaptir/edit.php','ou='.$ou.'&server_id='.$server_id));
	// following needs to work properly first
	//$GLOBALS['phpgw']->template->set_var('addobj_url',$GLOBALS['phpgw']->link('/eldaptir/addobj.php','dn='.$dn));
	$GLOBALS['phpgw']->template->set_var('addobj_url',$GLOBALS['phpgw']->link('/eldaptir/addobj.php','ou='.$ou.'&dn='.urlencode($dn).'&server_id='.$server_id));
	$GLOBALS['phpgw']->template->set_var('hidden_vars','<input type="hidden" name ="dn" value="'.urlencode($dn).'">');
	$GLOBALS['phpgw']->template->set_var('cancel_url',$GLOBALS['phpgw']->link('/eldaptir/viewou.php','ou='.$ou.'&nisMapName='.$nisMapName.'&server_id='.$server_id));

	$thisdn   = urldecode($dn);
	if ($addobj)
	{
		while(list($key,$oc) = each($ldapobj->schema->objectclasses))
		{
			eval("if \(\$\$oc=='on'\) { \$newoc \.= \$oc\.';'; }");
		}
		$addto = explode(';',$newoc);
		$ldapobj->form_addobj($thisdn,$addto);
	}

	$userData = $ldapobj->read($thisdn);
	$GLOBALS['phpgw']->template->set_var('dn',$codecv->utf8toeuc($thisdn));
	$GLOBALS['phpgw']->template->pparse('out','header');

	while (list($key,$objectclass) = each($userData[0]['objectclass']))
	{
		if (gettype($objectclass) == 'string')
		{
			$object = strtolower($objectclass);
			$tr_color = $GLOBALS['phpgw']->nextmatchs->alternate_row_color($tr_color);
			$GLOBALS['phpgw']->template->set_var(tr_color,$tr_color);
			$GLOBALS['phpgw']->template->set_var('objectclass',$object);
			$GLOBALS['phpgw']->template->set_var('row_name','&nbsp;');
			$GLOBALS['phpgw']->template->set_var('row_value','&nbsp;');
			$GLOBALS['phpgw']->template->set_var('row_rule','&nbsp;');
			$GLOBALS['phpgw']->template->parse("rows","row",True);
			$GLOBALS['phpgw']->template->pparse('out','row');
			if (is_array($ldapobj->schema->$object))
			{
				while(list($attrib,$req) = each($ldapobj->schema->$object))
				{
					$lattrib = strtolower($attrib);
					if ($req) { $required = lang('required'); }
					else { $required = lang('optional'); }
					if (isset($userData[0][$lattrib][0]) || isset($userData[0][$attrib][0]))
					{
						if ($userData[0][$attrib])
						{
							$tr_color = $GLOBALS['phpgw']->nextmatchs->alternate_row_color($tr_color);
							$GLOBALS['phpgw']->template->set_var(tr_color,$tr_color);
							$GLOBALS['phpgw']->template->set_var('objectclass','&nbsp;');
							$GLOBALS['phpgw']->template->set_var('row_name',$attrib);
							$GLOBALS['phpgw']->template->set_var('row_value','<input size="30" name="'.$object.'['.strtolower($attrib).']" value="'.$codecv->utf8toeuc($userData[0][$attrib][0]).'">');
							$GLOBALS['phpgw']->template->set_var('row_rule',$required);
							$GLOBALS['phpgw']->template->parse("rows","row",True);
						}
						else
						{
							$tr_color = $GLOBALS['phpgw']->nextmatchs->alternate_row_color($tr_color);
							$GLOBALS['phpgw']->template->set_var(tr_color,$tr_color);
							$GLOBALS['phpgw']->template->set_var('objectclass','&nbsp;');
							$GLOBALS['phpgw']->template->set_var('row_name',$attrib);
							$GLOBALS['phpgw']->template->set_var('row_value','<input size="30" name="'.$object.'['.strtolower($lattrib).']" value="'.$codecv->utf8toeuc($userData[0][$lattrib][0]).'">');
							$GLOBALS['phpgw']->template->set_var('row_rule',$required);
							$GLOBALS['phpgw']->template->parse("rows","row",True);
						}
					}
					else
					{
						$tr_color = $GLOBALS['phpgw']->nextmatchs->alternate_row_color($tr_color);
						$GLOBALS['phpgw']->template->set_var(tr_color,$tr_color);
						$GLOBALS['phpgw']->template->set_var('objectclass','&nbsp;');
						$GLOBALS['phpgw']->template->set_var('row_name',$attrib);
						$GLOBALS['phpgw']->template->set_var('row_value','<input size="30" name="'.$object.'['.strtolower($attrib).']" value="">');
						$GLOBALS['phpgw']->template->set_var('row_rule',$required);
						$GLOBALS['phpgw']->template->parse("rows","row",True);
					}
					$GLOBALS['phpgw']->template->pparse('out','row');
				}
			}
		}
	}

	$GLOBALS['phpgw']->template->pparse('out','footer');
	$GLOBALS['phpgw']->common->phpgw_footer();
?>

==> phpgroupware-jp-0.9.16.012-pre1.tar.bz2: phpgroupware/eldaptir/edit.php <==
<?php
	/**************************************************************************\
	* phpGroupWare - - eLDAPtir - LDAP Administration                          *
	* http://www.phpgroupware.org                                              *
	* Written by Miles Lott <milosch@phpgroupware.org>                         *
	* --------------------------------------------                             *
	*  This program is free software; you can redistribute it and/or modify it *
	*  under the terms of the GNU General Public License as published by the   *
	*  Free Software Foundation; either version 2 of the License, or (at your  *
	*  option) any later version.                                              *
	\**************************************************************************/

	/* $Id: edit.php,v 1.1.1.2.26.1 2007/09/14 02:11:31 kazuyan Exp $ */

	$dn = $_GET['dn'] ? @urldecode($_GET['dn']) : $_POST['dn'];
	$ou = $_GET['ou'] ? @urldecode($_GET['ou']) : $_POST['ou'];
	if (!$dn)
	{
		$GLOBALS['phpgw_info']['flags'] = array(
			'noappheader' => True,
			'nonavbar'    => True,
			'noheader'    => True
		);
		include('../header.inc.php');
		Header('Location: ' . $GLOBALS['phpgw']->link('/eldaptir/index.php'));
	}

	$GLOBALS['phpgw_info']['flags'] = array(
		'enable_nextmatchs_class' => True,
		'currentapp'              => 'eldaptir',
		'parent_page'             => 'viewou.php'
	);
	include('../header.inc.php');
	$server_id = get_var('server_id', array('GET', 'POST'));
    foreach($_POST as $key => $val)
    {
    	$$key = get_var($key,array('POST'));
    }
	$servers = servers();
	$server_type = $servers[$server_id]['type'];
	$ldapobj = CreateObject('eldaptir.ldap',$servers[$server_id]);
	$codecv = CreateObject('phpgwapi.codecv');

	if ($submit && $dn)
	{
		// This doesn't touch LDAP yet, just displays what might occur
		echo "<br />Form values:";
		$thisdn = urldecode($dn);
		$entry  = $ldapobj->read($thisdn);
		unset($ldapobj->entry);
		while (list($key,$objectclass) = each($entry[0]['objectclass']))
		{
			$object = strtolower($objectclass);
			if($ldapobj->schema->$object)
			{
				echo "<br /><br />Checking: ".$object."\n";
				@reset($ldapobj->schema->$object);
				$ldapobj->entry['objectclass'][] = $object;
				while(list($attrib,$req) = @each($ldapobj->schema->$object))
				{
					$lattrib = strtolower($attrib);		
					echo "<br />". $object."[".$lattrib."] = "
						. ${$object}[$lattrib]."\n";

					if (${$object}[$lattrib] && !$ldapobj->entry[$lattrib])
					{
						$ldapobj->entry[$lattrib] = $codecv->euctoutf8(${$object}[$lattrib]);
					}
					elseif ((!isset(${$object}[$lattrib]) || ${$object}[$lattrib] == '') && $entry[0][$lattrib])
					{
						$ldapobj->entry[$lattrib] = Array();
					}
				}
			}
		}
		echo "<br /><br />Entry values:";
		while (list($key,$val) = each($entry[0]))
		{
			if($ldapobj->clean($val))
			{
				if (is_array($val))
				{
					while(list($v) = each($val))
					{
						if($ldapobj->clean($v))
						{
							echo '<br />arr '.$codecv->utf8toeuc($v).': '.$codecv->utf8toeuc($entry[0][$v][0])."\n";
						}
					}
				}
				else
				{
					echo '<br />str '.$codecv->utf8toeuc($val).': '.$codecv->utf8toeuc($entry[0][$val][0])."\n";
				}
			}
		}
		$ldapobj->update($thisdn);
		echo '<div align="center"><a href="'.$GLOBALS['phpgw']->link('/eldaptir/viewou.php','ou='.$ou.'&nisMapName='.$nisMapName.'&server_id='.$server_id).
		'">'.lang('Back').'</a></div>';
		$GLOBALS['phpgw']->common->phpgw_footer();
		exit;
		//...
	}

	$GLOBALS['phpgw']->template->set_unknowns('remove');
	$GLOBALS['phpgw']->template->set_file(array('edit' => 'edit.tpl'));
	$GLOBALS['phpgw']->template->set_block('edit','header','header');
	$GLOBALS['phpgw']->template->set_block('edit','row','row');
	$GLOBALS['phpgw']->template->set_block('edit','footer','footer');

	$GLOBALS['phpgw']->template->set_var('title','<a href="'.$GLOBALS['phpgw']->link('/eldaptir','server_id='.$server_id).'">'.lang("eldaptir")."</a>\n");
	$GLOBALS['phpgw']->template->set_var('th_bg',$GLOBALS['phpgw_info']['theme']['th_bg']);
	$GLOBALS['phpgw']->template->set_var('tr_color1',$GLOBALS['phpgw_info']['theme']['row_on']);
	$GLOBALS['phpgw']->template->set_var('tr_color2',$GLOBALS['phpgw_info']['theme']['row_off']);
	$GLOBALS['phpgw']->template->set_var('lang_cancel',lang('Cancel'));
	$GLOBALS['phpgw']->template->set_var('lang_addobj',lang('Add').' '.lang('Objectclass'));
	$GLOBALS['phpgw']->template->set_var('lang_submit',lang('Submit'));
	$GLOBALS['phpgw']->template->set_var('lang_dn',lang('dn'));
	$GLOBALS['phpgw']->template->set_var('lang_obj',lang('Objectclass'));
	$GLOBALS['phpgw']->template->set_var('lang_attr',lang('Attribute'));
	$GLOBALS['phpgw']->template->set_var('lang_value',lang('Value'));
	$GLOBALS['phpgw']->template->set_var('lang_rule',lang('Rule'));
	$GLOBALS['phpgw']->template->set_var('action_url',$GLOBALS['phpgw']->link('/eldaptir/edit.php','ou='.$ou.'&server_id='.$server_id));
	// following needs to work properly first
	//$GLOBALS['phpgw']->template->set_var('addobj_url',$GLOBALS['phpgw']->link('/eldaptir/addobj.php','dn='.$dn));
	$GLOBALS['phpgw']->template->set_var('addobj_url',$GLOBALS['phpgw']->link('/eldaptir/addobj.php','ou='.$ou.'&dn='.urlencode($dn).'&server_id='.$server_id));
	$GLOBALS['phpgw']->template->set_var('hidden_vars','<input type="hidden" name ="dn" value="'.urlencode($dn).'">');
	$GLOBALS['phpgw']->template->set_var('cancel_url',$GLOBALS['phpgw']->link('/eldaptir/viewou.php','ou='.$ou.'&nisMapName='.$nisMapName.'&server_id='.$server_id));

	$thisdn   = urldecode($dn);
	if ($addobj)
	{
		while(list($key,$oc) = each($ldapobj->schema->objectclasses))
		{
			eval("if \(\$\$oc=='on'\) { \$newoc \.= \$oc\.';'; }");
		}
		$addto = explode(';',$newoc);
		$ldapobj->form_addobj($thisdn,$addto);
	}

	$userData = $ldapobj->read($thisdn);
	$GLOBALS['phpgw']->template->set_var('dn',$codecv->utf8toeuc($thisdn));
	$GLOBALS['phpgw']->template->pparse('out','header');

	while (list($key,$objectclass) = each($userData[0]['objectclass']))
	{
		if (gettype($objectclass) == 'string')
		{
			$object = strtolower($objectclass);
			$tr_color = $GLOBALS['phpgw']->nextmatchs->alternate_row_color($tr_color);
			$GLOBALS['phpgw']->template->set_var(tr_color,$tr_color);
			$GLOBALS['phpgw']->template->set_var('objectclass',$object);
			$GLOBALS['phpgw']->template->set_var('row_name','&nbsp;');
			$GLOBALS['phpgw']->template->set_var('row_value','&nbsp;');
			$GLOBALS['phpgw']->template->set_var('row_rule','&nbsp;');
			$GLOBALS['phpgw']->template->parse("rows","row",True);
			$GLOBALS['phpgw']->template->pparse('out','row');
			if (is_array($ldapobj->schema->$object))
			{
				while(list($attrib,$req) = each($ldapobj->schema->$object))
				{
					$lattrib = strtolower($attrib);
					if ($req) { $required = lang('required'); }
					else { $required = lang('optional'); }
					if (isset($userData[0][$lattrib][0]) || isset($userData[0][$attrib][0]))
					{
						if ($userData[0][$attrib])
						{
							$tr_color = $GLOBALS['phpgw']->nextmatchs->alternate_row_color($tr_color);
							$GLOBALS['phpgw']->template->set_var(tr_color,$tr_color);
							$GLOBALS['phpgw']->template->set_var('objectclass','&nbsp;');
							$GLOBALS['phpgw']->template->set_var('row_name',$attrib);
							$GLOBALS['phpgw']->template->set_var('row_value','<input size="30" name="'.$object.'['.strtolower($attrib).']" value="'.$codecv->utf8toeuc($userData[0][$attrib][0]).'">');
							$GLOBALS['phpgw']->template->set_var('row_rule',$required);
							$GLOBALS['phpgw']->template->parse("rows","row",True);
						}
						else
						{
							$tr_color = $GLOBALS['phpgw']->nextmatchs->alternate_row_color($tr_color);
							$GLOBALS['phpgw']->template->set_var(tr_color,$tr_color);
							$GLOBALS['phpgw']->template->set_var('objectclass','&nbsp;');
							$GLOBALS['phpgw']->template->set_var('row_name',$attrib);
							$GLOBALS['phpgw']->template->set_var('row_value','<input size="30" name="'.$object.'['.strtolower($lattrib).']" value="'.$codecv->utf8toeuc($userData[0][$lattrib][0]).'">');
							$GLOBALS['phpgw']->template->set_var('row_rule',$required);
							$GLOBALS['phpgw']->template->parse("rows","row",True);
						}
					}
					else
					{
						$tr_color = $GLOBALS['phpgw']->nextmatchs->alternate_row_color($tr_color);
						$GLOBALS['phpgw']->template->set_var(tr_color,$tr_color);
						$GLOBALS['phpgw']->template->set_var('objectclass','&nbsp;');
						$GLOBALS['phpgw']->template->set_var('row_name',$attrib);
						$GLOBALS['phpgw']->template->set_var('row_value','<input size="30" name="'.$object.'['.strtolower($attrib).']" value="">');
						$GLOBALS['phpgw']->template->set_var('row_rule',$required);
						$GLOBALS['phpgw']->template->parse("rows","row",True);
					}
					$GLOBALS['phpgw']->template->pparse('out','row');
				}
			}
		}
	}

	$GLOBALS['phpgw']->template->pparse('out','footer');
	$GLOBALS['phpgw']->common->phpgw_footer();
?>
